@@ -4,7 +4,7 @@ import os
 
 from mopidy import config, ext
 
-__version__ = '0.2.1'
+__version__ = '0.2.4'
 
 
 class Extension(ext.Extension):
@@ -19,14 +19,14 @@ class Extension(ext.Extension):
 
     def get_config_schema(self):
         schema = super(Extension, self).get_config_schema()
-        schema['username'] = config.String()
-        schema['password'] = config.Secret()
-        schema['quality'] = config.String()
-        schema['difm'] = config.Boolean()
-        schema['radiotunes'] = config.Boolean()
-        schema['rockradio'] = config.Boolean()
-        schema['jazzradio'] = config.Boolean()
-        schema['frescaradio'] = config.Boolean()
+        schema['username'] = config.String(optional=True)
+        schema['password'] = config.Secret(optional=True)
+        schema['quality'] = config.String(optional=True)
+        schema['difm'] = config.Boolean(optional=True)
+        schema['radiotunes'] = config.Boolean(optional=True)
+        schema['rockradio'] = config.Boolean(optional=True)
+        schema['jazzradio'] = config.Boolean(optional=True)
+        schema['frescaradio'] = config.Boolean(optional=True)
         return schema
 
     def setup(self, registry):
