@@ -25,23 +25,32 @@ class AudioAddict(object):
         self._frescaradio = frescaradio
 
         # Figure out our API key
-        if len(self._username) and len(self._password):
-            self._api_key = self._fetchApiKey(self._username, self._password)
+        if self._username and self._password:
+            self._api_key, self._has_premium = self._fetchApiKey(self._username, self._password)
         else:
-            self._api_key = ""
+            self._api_key = None
+            self._has_premium = False
 
     def flush(self):
         self._cache = {}
         self._channels = {}
 
     def radiostations(self, radiostation=None):
-        stationlist = [
-            {'id': 1, 'name': 'Digitally Imported', 'shortcode': 'difm',},
-            {'id': 2, 'name': 'RadioTunes', 'shortcode': 'radiotunes',},
-            {'id': 3, 'name': 'RockRadio', 'shortcode': 'rockradio',},
-            {'id': 4, 'name': 'JazzRadio', 'shortcode': 'jazzradio',},
-            {'id': 5, 'name': 'FrescaRadio', 'shortcode': 'frescaradio',}
-        ]
+        stationlist = []
+        if self._difm:
+            stationlist.append({'id': 1, 'name': 'Digitally Imported', 'shortcode': 'difm'})
+        if self._radiotunes:
+            stationlist.append({'id': 2, 'name': 'RadioTunes', 'shortcode': 'radiotunes'})
+        if self._rockradio:
+            stationlist.append({'id': 3, 'name': 'RockRadio', 'shortcode': 'rockradio'})
+        if self._jazzradio:
+            stationlist.append({'id': 4, 'name': 'JazzRadio', 'shortcode': 'jazzradio'})
+        if self._frescaradio:
+            stationlist.append({'id': 5, 'name': 'FrescaRadio', 'shortcode': 'frescaradio'})
+
+        if not stationlist:
+            # Default to at least one network
+            stationlist.append({'id': 1, 'name': 'Digitally Imported', 'shortcode': 'difm'})
 
         return stationlist
 
@@ -66,20 +75,23 @@ class AudioAddict(object):
         else:
             return []
 
-        if (len(self._api_key)):
-            if (self._quality == '320k'):
+        if self._api_key and self._has_premium:
+            if self._quality:
+                if (self._quality == '320k'):
+                    streampls = 'premium_high'
+                if (self._quality == '128k'):
+                    streampls = 'premium'
+                if (self._quality == '64k'):
+                    streampls = 'premium_medium'
+                if (self._quality == '40k'):
+                    streampls = 'premium_low'
+            else:
                 streampls = 'premium_high'
-            if (self._quality == '128k'):
-                streampls = 'premium'
-            if (self._quality == '64k'):
-                streampls = 'premium_medium'
-            if (self._quality == '40k'):
-                streampls = 'premium_low'
         else:
             streampls = 'public3'
 
         for channel in channels:
-            if (len(self._api_key)):
+            if self._api_key:
                 channel['streamurl'] = 'http://' + hostname + '/' + streampls + '/' + channel['key'] + '.pls?' + self._api_key
             else:
                 channel['streamurl'] = 'http://' + hostname + '/' + streampls + '/' + channel['key'] + '.pls'
@@ -101,7 +113,16 @@ class AudioAddict(object):
         payload = {'username': username, 'password': password}
         r = requests.post("https://api.audioaddict.com/v1/di/members/authenticate", data=payload)
         json_object_raw = r.json()
-        return json_object_raw['listen_key']
+
+        subscriptions = json_object_raw['subscriptions']
+        listen_key = json_object_raw['listen_key']
+
+        if not subscriptions:
+            has_premium = False
+        else:
+            has_premium = True
+
+        return (listen_key, has_premium)
 
     def _fetch(self, uri, default):
         if uri in self._cache:
